<template>
  <a-card :bordered="false">
    <a-row :gutter="8">
      <a-col :span="5">
        <a-tree
          @expand="onExpand"
          :expandedKeys="expandedKeys"
          :autoExpandParent="autoExpandParent"
          @select="onSelect"
          :selectedKeys="selectedKeys"
          :treeData="fillProjectQuantityTree"
        />
      </a-col>
      <a-col :span="19">
        <div class="table-page-search-wrapper" @keyup.enter="handleEnter">
          <a-form layout="inline">
            <a-row :gutter="48">
              <a-col :md="8" :sm="24">
                <a-form-item label="关键字">
                  <a-input v-model="queryParam.keyword" placeholder="请输入名称/类型名称"/>
                </a-form-item>
              </a-col>
              <a-col :md="8" :sm="24">
                <a-form-item label="部门">
                  <a-tree-select
                    v-model="queryParam.deptCode"
                    :treeNodeFilterProp="'title'"
                    placeholder="请选择部门"
                    :allow-clear="true"
                    :show-search="true"
                    :replaceFields="{children:'children', title:'title', key:'key', value: 'deptCode' }"
                    :tree-default-expand-all="true"
                    :dropdown-style="{ maxHeight: '400px', overflow: 'auto' }"
                    :treeData="treeData"
                  />
                </a-form-item>
              </a-col>
              <a-col :md="8 || 24" :sm="24">
                <span class="table-page-search-submitButtons">
                  <a-button type="primary" @click="$refs.table.refresh(true)">查询</a-button>
                  <a-button style="margin-left: 8px" @click="resetSearchForm">重置</a-button>
                </span>
              </a-col>
            </a-row>
          </a-form>
        </div>

        <div class="table-operator">
          <a-button v-if="$auth('fill-project-quantities-add')" type="primary" icon="plus" @click="$refs.baseModal.base({}, {parentItem: selectedItem})">新增</a-button>
          <a-button style="margin-left: 8px" v-if="$auth('fill-project-quantities-export')" type="primary" icon="download" @click="doExport">导出</a-button>
          <a-button style="margin-left: 8px" type="primary" icon="download" @click="doImport">导入</a-button>
          <a-dropdown v-action:edit v-if="selectedRowKeys.length > 0 && $auth('fill-project-quantities-del')">
            <a-menu slot="overlay">
              <a-popconfirm title="是否要删除所选数据？" @confirm="batchDelete()">
                <a-menu-item key="1"><a-icon type="delete" /><a>删除</a></a-menu-item>
              </a-popconfirm>
            </a-menu>
            <a-button style="margin-left: 8px">
              批量操作 <a-icon type="down" />
            </a-button>
          </a-dropdown>
        </div>

        <s-table
          ref="table"
          size="default"
          rowKey="id"
          :bordered="this.MyGlobalConstant.BORDERED"
          :columns="columns"
          :data="loadData"
          :alert="options.alert"
          :rowSelection="options.rowSelection"
          showPagination="auto"
        >
          <span slot="action" slot-scope="record">
            <template>
              <a @click="handleView(record)">查看</a>
              <operation-button
                v-if="$auth('fill-project-quantities-edit')"
                @click="handleEdit(record)"
              >修改</operation-button>

              <operation-button
                :type="2"
                :title="'是否要'+(record.closeProject?'开启':'关闭')+'该条数据？'"
                @confirm="updateClose(record)">{{ record.closeProject?'开启':'关闭' }}</operation-button>

              <operation-button
                v-if="$auth('fill-project-quantities-del')"
                :type="2"
                title="是否要删除该条数据？"
                @confirm="batchDelete(record.id)">删除</operation-button>
            </template>
          </span>
        </s-table>
      </a-col>
    </a-row>
    <base-form ref="baseModal" @ok="handleOk"/>
    <detail ref="detailModal"/>
    <import-form ref="importForm" @save="importDataSave" />
  </a-card>
</template>

<script>
import { STable, Ellipsis } from '@/components'
import BaseForm from './modules/BaseForm'
import Detail from './modules/Detail'
import { getFillProjectQuantityPage, getFillProjectQuantityDeptTree, updateCloseProject,
  deleteFillProjectQuantitys, fetchFillProjectQuantity, exportFillProjectQuantity, importProject } from '@/api/fill/project-quantity'
import { getDeptTree } from '@/api/upms/dept'

export default {
  name: 'FillProjectQuantityList',
  components: {
    STable,
    Ellipsis,
    BaseForm,
    Detail
  },
  data () {
    return {
      // 查询参数
      queryParam: {
      },
      selectedKeys: [],
      selectedItem: {},
      expandedKeys: [],
      treeData: [],
      fillProjectQuantityTree: [],
      autoExpandParent: true,
      // 表头
      columns: [
        {
          title: '序号',
          dataIndex: 'index',
          customRender: (text, record, index) => {
            return `${(this.$refs.table.localPagination.current - 1) * this.$refs.table.localPagination.pageSize + index + 1}`
          }
        },
        {
          title: '部门',
          dataIndex: 'deptName'
        },
        {
          title: '章次',
          dataIndex: 'surah'
        },
        {
          title: '名称',
          dataIndex: 'name'
        },
        {
          title: '单位',
          dataIndex: 'unit',
          customRender: (text, record, index) => {
            return this.BaseTool.Table.getMapText(this.unitMap, text)
          }
        },
        {
          title: '位置单位',
          dataIndex: 'siteUnit',
          customRender: (text, record, index) => {
            return this.BaseTool.Table.getMapText(this.unitMap, text)
          }
        },
        {
          title: '总量',
          dataIndex: 'aggregate',
          customRender: (text, record, index) => {
            return this.BaseTool.Amount.formatter(text)
          }
        },
        {
          title: '单价',
          dataIndex: 'price',
          customRender: (text, record, index) => {
            return this.BaseTool.Amount.formatter(text)
          }
        },
        {
          title: '总价',
          dataIndex: 'totalPrice',
          customRender: (text, record, index) => {
            return this.BaseTool.Amount.formatter(text)
          }
        },
        {
          title: '备注',
          dataIndex: 'remark'
        },
        {
          title: '创建人名称',
          dataIndex: 'createdUserName'
        },
        {
          title: '创建日期',
          dataIndex: 'createdTime'
        },
        {
          title: '操作',
          key: 'action',
          width: '200px',
          align: 'center',
          scopedSlots: { customRender: 'action' }
        }
      ],
      // 下拉框map
      unitMap: {},
      // 加载数据方法 必须为 Promise 对象
      loadData: parameter => {
        parameter = {
          ...parameter,
          ...this.queryParam
        }
        return getFillProjectQuantityPage(parameter)
          .then(res => {
            return res.data
          })
      },
      selectedRowKeys: [],
      selectedRows: [],

      options: {
        alert: { show: true, clear: () => { this.selectedRowKeys = [] } },
        rowSelection: {
          selectedRowKeys: this.selectedRowKeys,
          onChange: this.onSelectChange
        }
      },
      optionAlertShow: false
    }
  },
  created () {
    // 下拉框map
    this.unitMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.FILL_PROJECT_QUANTITY_UNIT)
    this.initData()
    getDeptTree().then(res => {
      this.treeData = this.BaseTool.TREE.treeFilter(res.data, (item) => {
        if (item.item.nature === this.DictCache.VALUE.SYS_DEPT_NATURE.BAN_ZU) {
          return { delete: true }
        }
        item.deptCode = item.item.deptCode
      })
    })
    this.tableOption()
  },
  methods: {
    initData () {
      getFillProjectQuantityDeptTree().then(res => {
        this.fillProjectQuantityTree = this.BaseTool.TREE.treeFilter(res.data, (item) => {
          if (item.icon) {
            item.selectable = false
          }
        })
      })
    },
    tableOption () {
      if (!this.optionAlertShow) {
        this.options = {
          alert: { show: true, clear: () => { this.selectedRowKeys = [] } },
          rowSelection: {
            selectedRowKeys: this.selectedRowKeys,
            onChange: this.onSelectChange,
            getCheckboxProps: record => ({
              props: {
                disabled: false,
                name: record.id
              }
            })
          }
        }
        this.optionAlertShow = true
      } else {
        this.options = {
          alert: false,
          rowSelection: null
        }
        this.optionAlertShow = false
      }
    },
    batchDelete (id) {
      let ids = []
      if (this.BaseTool.String.isBlank(id)) {
        const length = this.selectedRows.length
        if (length === 0) {
          this.$message.info('请选择要删除的记录')
          return
        }
        ids = this.selectedRows.map(item => item.id)
      } else {
        ids = [id]
      }
      deleteFillProjectQuantitys(ids).then(res => {
        this.$message.info('删除成功')
        this.handleOk()
        this.$refs.table.clearSelected()
      })
    },
    updateClose (record) {
      updateCloseProject({ id: record.id, closeProject: !record.closeProject }).then(res => {
        this.$message.info('操作成功')
        this.handleOk()
      })
    },
    handleEdit (record) {
      fetchFillProjectQuantity({ id: record.id }).then(res => {
        const modal = this.$refs.baseModal
        modal.base(res.data)
      })
    },
    handleView (record) {
      fetchFillProjectQuantity({ id: record.id }).then(res => {
        const modal = this.$refs.detailModal
        modal.base(res.data)
      })
    },
    handleOk () {
      this.initData()
      this.$refs.table.refresh()
    },
    onSelectChange (selectedRowKeys, selectedRows) {
      this.selectedRowKeys = selectedRowKeys
      this.selectedRows = selectedRows
    },
    resetSearchForm () {
      this.queryParam = {
      }
      this.selectedKeys = []
      this.selectedItem = {}
      this.$refs.table.refresh(true)
    },
    doImport () {
      this.$refs.importForm.base()
    },
    importDataSave (file, callback) {
      const result = importProject(file)
        .then((res) => {
          console.log(11111)
          this.handleOk()
        })
      callback(result)
    },
    doExport () {
      const parameter = {
        ...this.queryParam
      }
      exportFillProjectQuantity(parameter).then(file => {
        this.BaseTool.UPLOAD.downLoadExportExcel(file)
      })
    },
    handleEnter () {
      this.$refs.table.refresh(true)
    },
    onSelect: function (selectedKeys, info) {
      this.selectedKeys = selectedKeys
      if (selectedKeys != null && selectedKeys.length > 0) {
        const select = info.node.$options.propsData.dataRef
        if (!select.icon) {
          this.selectedItem = info.node.$options.propsData.dataRef.item
          this.queryParam.parentId = selectedKeys.length > 0 ? selectedKeys[0] : ''
        } else {
          this.selectedItem = {}
          this.queryParam.parentId = null
          this.queryParam.deptCode = info.node.$options.propsData.dataRef.item.deptCode
        }
      } else {
        this.selectedItem = {}
        this.queryParam.parentId = null
        this.queryParam.deptId = null
      }
      this.$refs.table.refresh(true)
    },
    onExpand (expandedKeys) {
      this.expandedKeys = expandedKeys
      this.autoExpandParent = false
    }
  }
}
</script>
